@@ -91,6 +91,7 @@ int dasd_sys_ese(char *devnode)
 
 	rc = fgetc(fp) - '0';
 	fclose(fp);
+	free(path);
 
 	return (rc == 1) ? 1 : 0;
 }
@@ -218,7 +219,8 @@ int dasd_get_host_access_count(char *device)
 		return 0;
 
 	path = util_path_sysfs("bus/ccw/devices/%s/host_access_count", busid);
-	util_file_read_l(&value, 10, path);
+	if (util_file_read_l(&value, 10, path))
+		value = 0;
 	free(path);
 
 	return value;
